@@ -16,13 +16,14 @@
 
 import sys
 from calculate.core.server.func import Action, Tasks
-from calculate.install.distr import DistributiveError
-from calculate.install.migrate_users import MigrationError
-from calculate.install.variables.autopartition import AutopartitionError
+from ..distr import DistributiveError
+from ..migrate_users import MigrationError
+from ..variables.autopartition import AutopartitionError
+from calculate.lib.utils.partition import VolumesError
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate, _
 from calculate.lib.cl_template import TemplatesError
 from calculate.lib.utils.files import FilesError
-from calculate.install.install import InstallError
+from ..install import InstallError
 
 setLocalTranslate('cl_install3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
@@ -33,7 +34,7 @@ class ClInstallAction(Action):
     Установка системы
     """
     # ошибки, которые отображаются без подробностей
-    native_error = (FilesError, MigrationError, TemplatesError,
+    native_error = (FilesError, MigrationError, TemplatesError, VolumesError,
                     InstallError, AutopartitionError, DistributiveError)
     successMessage = None
     failedMessage = None
@@ -44,11 +45,9 @@ class ClInstallAction(Action):
         # авторазметка диска
         {'name': 'autopartition',
          'message': __("Creating a new partition table"),
-         'method': "Install.autopartition(cl_autopartition_table,"
-                   "cl_autopartition_device,cl_autopartition_disk_data,"
-                   "cl_autopartition_lvm_set,cl_autopartition_lvm_vgname,"
-                   "cl_autopartition_bios_grub_set,"
-                   "cl_autopartition_bios_grub_size)",
+         'method': "Install.autopartition(cl_autopartition_scheme_builder,"
+                                         "cl_autopartition_device,"
+                                         "cl_autopartition_disk_dev)",
          'condition': lambda dv: dv.Get('cl_autopartition_set') == 'on'},
         # форматирование разделов на которые устанавливается дистрибутив
         {'name': 'format',
